@@ -588,8 +588,9 @@ static int create_new_header(struct reenc_ctx *rc, struct crypt_device *cd_old,
 		goto out;
 	}
 
-	if ((r = crypt_format(cd_new, type, cipher, cipher_mode,
-			      uuid, key, key_size, params)))
+	r = crypt_format(cd_new, type, cipher, cipher_mode, uuid, key, key_size, params);
+	check_signal(&r);
+	if (r < 0)
 		goto out;
 	log_verbose(_("New LUKS header for device %s created."), rc->device);
 
@@ -598,9 +599,10 @@ static int create_new_header(struct reenc_ctx *rc, struct crypt_device *cd_old,
 			continue;
 
 		r = create_new_keyslot(rc, i, cd_old, cd_new);
+		check_signal(&r);
 		if (r < 0)
 			goto out;
-		log_verbose(_("Activated keyslot %i."), r);
+		tools_keyslot_msg(r, CREATED);
 		r = 0;
 	}
 out:
@@ -721,7 +723,7 @@ static int backup_luks_headers(struct reenc_ctx *rc)
 		if ((r = chmod(rc->header_file_tmp, st.st_mode | S_IWUSR)))
 			goto out;
 	}
-	log_verbose(_("%s header backup of device %s created."), rc->device, isLUKS2(rc->type) ? "LUKS2" : "LUKS1");
+	log_verbose(_("%s header backup of device %s created."), isLUKS2(rc->type) ? "LUKS2" : "LUKS1", rc->device);
 
 	/* For decrypt, new header will be fake one, so we are done here. */
 	if (rc->reencrypt_mode == DECRYPT)
@@ -835,11 +837,13 @@ static int backup_fake_header(struct reenc_ctx *rc)
 
 	r = crypt_format(cd_new, CRYPT_LUKS1, "cipher_null", "ecb",
 			 NO_UUID, NULL, opt_key_size / 8, &params);
+	check_signal(&r);
 	if (r < 0)
 		goto out;
 
 	r = crypt_keyslot_add_by_volume_key(cd_new, rc->keyslot, NULL, 0,
 			rc->p[rc->keyslot].password, rc->p[rc->keyslot].passwordLen);
+	check_signal(&r);
 	if (r < 0)
 		goto out;
 
@@ -916,9 +920,9 @@ static int restore_luks_header(struct reenc_ctx *rc)
 	crypt_free(cd);
 out:
 	if (r)
-		log_err(_("Cannot restore %s header on device %s."), hdr_device(rc), isLUKS2(rc->type) ? "LUKS2" : "LUKS1");
+		log_err(_("Cannot restore %s header on device %s."), isLUKS2(rc->type) ? "LUKS2" : "LUKS1", hdr_device(rc));
 	else {
-		log_verbose(_("%s header on device %s restored."), hdr_device(rc), isLUKS2(rc->type) ? "LUKS2" : "LUKS1");
+		log_verbose(_("%s header on device %s restored."), isLUKS2(rc->type) ? "LUKS2" : "LUKS1", hdr_device(rc));
 		rc->stained = 0;
 	}
 	return r;
@@ -1271,6 +1275,7 @@ static int init_passphrase1(struct reenc_ctx *rc, struct crypt_device *cd,
 			return r;
 
 		if (r >= 0) {
+			tools_keyslot_msg(r, UNLOCKED);
 			rc->p[r].password = password;
 			rc->p[r].passwordLen = passwordLen;
 			if (ki != CRYPT_SLOT_UNBOUND)
@@ -1534,6 +1539,8 @@ static int run_reencrypt(const char *device)
 		.stained = 1
 	};
 
+	set_int_handler(0);
+
 	if (initialize_context(&rc, device))
 		goto out;
 
@@ -1551,7 +1558,7 @@ static int run_reencrypt(const char *device)
 
 		log_dbg("Storing backup of LUKS headers.");
 		if (rc.reencrypt_mode == ENCRYPT) {
-			/* Create fake header for exising device */
+			/* Create fake header for existing device */
 			if ((r = backup_fake_header(&rc)))
 				goto out;
 		} else {
@@ -1653,8 +1660,6 @@ int main(int argc, const char **argv)
 
 	crypt_set_log_callback(NULL, tool_log, NULL);
 
-	set_int_block(1);
-
 	setlocale(LC_ALL, "");
 	bindtextdomain(PACKAGE, LOCALEDIR);
 	textdomain(PACKAGE);
